Function drain

fn drain<'a, T: LazyBalanceMarker>(
    model: &'a mut LazyContainer<T>,
) -> Result<T::Asset, Error<T>>
Executes a drain operation on the lazy balance model.

Constructs the tagged input, invokes LazyBalance::drain.

Clears the balance state and returns the resolved drained value.